@@ -89,7 +89,7 @@ class Crawler:
                      invisible: bool = False,
                      _all: bool = False) -> WebElement:
         # ждем появления и возвращаем элемент по типу селектора и значению
-        wait = WebDriverWait(self.driver, 15)
+        wait = WebDriverWait(self.driver, 60)
         wait_condition = EC.visibility_of_element_located
         if _all:
             wait_condition = EC.presence_of_element_located
@@ -147,7 +147,8 @@ def attempted_crawling(attempts: int):
                         AttributeError,
                         WebDriverException,
                         exceptions.NotAuthorizeException,
-                        ElementClickInterceptedException):
+                        ElementClickInterceptedException) as e:
+                    logging.warning(e)
                     self.stop()
                     attempt += 1
             return schemas.BillingSchema(is_unrecognized=True)
@@ -167,20 +168,6 @@ def logg_func_execution(func):
     return echo_func
 
 
-def driver_hard_reset(func):
-    def wrapper(*args, **kwargs):
-        self = args[0]
-        result = func(*args, **kwargs)
-        try:
-            result.dict()
-            self.stop()
-        except AttributeError:
-            pass
-        return result
-
-    return wrapper
-
-
 class AmoPartnerCrawler(Crawler):
     """
     CLASS FOR SCRAPING BILLING DATA FROM AMO PARTNER CABINET
@@ -219,10 +206,13 @@ class AmoPartnerCrawler(Crawler):
         except exceptions.ElementHiddenException:
             return True
 
+    @logg_func_execution
     def check_tariff(self):
         tariff_select = self.wait_select_element(self.wait_element(Selector.by_id, 'tariff_id'))
         current_tariff_value = tariff_select.first_selected_option.get_attribute("value")
-        if int(current_tariff_value) in [22000000, 20533490, 8403805, 8404105]:
+
+        if not current_tariff_value.isdigit() or \
+                int(current_tariff_value) in [22000000, 20533490, 8404105]:
             raise exceptions.BadTariffException()
 
     @property
@@ -282,19 +272,20 @@ class AmoPartnerCrawler(Crawler):
         # подтверждение формы и переход к тоталу по введенным данным
         start_bill_button = self.wait_element(Selector.by_id, 'start_bill')
         self.click_on_element(start_bill_button)
+        self.wait(10)
 
     @logg_func_execution
     def extract_data(self) -> dict:
-        tariff = self.wait_element(Selector.by_xpath, "//div[contains(@class, 'tariff_value')]/input")
-        count_users = self.wait_element(Selector.by_xpath, "//div[contains(@class, 'col_user')]/div[2]/input")
-        pay_period = self.wait_element(Selector.by_xpath, "(//div[@class='row_field'])[3]/input")
-        price = self.wait_element(Selector.by_xpath, "(//div[@class='row_field'])[4]/input")
+
+        tariff = self.wait_element(Selector.by_xpath, "//div[contains(@class, 'tariff_value')]/input", _all=True)
+        count_users = self.wait_element(Selector.by_xpath, "//div[contains(@class, 'col_user')]/div[2]/input", _all=True)
+        pay_period = self.wait_element(Selector.by_xpath, "(//div[@class='row_field'])[3]/input", _all=True)
+        price = self.wait_element(Selector.by_xpath, "(//div[@class='row_field'])[4]/input", _all=True)
         return {'price': price.get_attribute('value'),
                 'users_count': count_users.get_attribute('value'),
                 'tariff': tariff.get_attribute('value'),
                 'pay_period': pay_period.get_attribute('value')}
 
-    @driver_hard_reset
     @attempted_crawling(attempts=3)
     def get_billing_data(self, account_id: int) -> schemas.BillingSchema:
         self.start()
@@ -308,10 +299,13 @@ class AmoPartnerCrawler(Crawler):
             self.approve_form()
             self.wait(5)
             data = self.extract_data()
+            self.stop()
             return schemas.BillingSchema(**data)
         except exceptions.AlreadyPaidException:
+            self.stop()
             return schemas.BillingSchema(is_paid=True)
         except (exceptions.IDNotFoundException,
                 exceptions.BadTariffException,
                 exceptions.FatalityException):
+            self.stop()
             return schemas.BillingSchema(is_unrecognized=True)
